==> customized-facade-1.0.3-20190813.113834-27-sources.jar: com/bizvane/customized/facade/models/vo/CusUrMbrGiftCardVO.java <==
package com.bizvane.customized.facade.models.vo;

import com.bizvane.customized.facade.models.po.CusUrMbrGiftCardPO;

import java.math.BigDecimal;
import java.util.List;

/**
 * @author liufq
 */
public class CusUrMbrGiftCardVO extends CusUrMbrGiftCardPO {
    private Integer number;
    private BigDecimal changeBlance;
    private List<String> cardNoList;
    private String startDate;
    private String endDate;
    private String excelUrl;
    private String opeType;
    private List<Long> giftCardIdList;
    private String startValidityDate;
    private String endValidityDate;
    private Integer pageNumber = 1;
    private Integer pageSize = 10;

    public Integer getNumber() {
        return number;
    }

    public void setNumber(Integer number) {
        this.number = number;
    }


    public BigDecimal getChangeBlance() {
        return changeBlance;
    }

    public void setChangeBlance(BigDecimal changeBlance) {
        this.changeBlance = changeBlance;
    }

    public List<String> getCardNoList() {
        return cardNoList;
    }

    public void setCardNoList(List<String> cardNoList) {
        this.cardNoList = cardNoList;
    }

    public String getStartDate() {
        return startDate;
    }

    public void setStartDate(String startDate) {
        this.startDate = startDate;
    }

    public String getEndDate() {
        return endDate;
    }

    public void setEndDate(String endDate) {
        this.endDate = endDate;
    }

    public String getExcelUrl() {
        return excelUrl;
    }

    public void setExcelUrl(String excelUrl) {
        this.excelUrl = excelUrl;
    }

    public String getOpeType() {
        return opeType;
    }

    public void setOpeType(String opeType) {
        this.opeType = opeType;
    }

    public List<Long> getGiftCardIdList() {
        return giftCardIdList;
    }

    public void setGiftCardIdList(List<Long> giftCardIdList) {
        this.giftCardIdList = giftCardIdList;
    }

    public Integer getPageNumber() {
        return pageNumber;
    }

    public void setPageNumber(Integer pageNumber) {
        this.pageNumber = pageNumber;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public String getStartValidityDate() {
        return startValidityDate;
    }

    public void setStartValidityDate(String startValidityDate) {
        this.startValidityDate = startValidityDate;
    }

    public String getEndValidityDate() {
        return endValidityDate;
    }

    public void setEndValidityDate(String endValidityDate) {
        this.endValidityDate = endValidityDate;
    }
}

==> customized-facade-20240906-20240902.095529-12-sources.jar: com/bizvane/customized/facade/models/vo/CusUrMbrGiftCardVO.java <==
package com.bizvane.customized.facade.models.vo;

import com.bizvane.customized.facade.models.po.CusUrMbrGiftCardPO;

import java.math.BigDecimal;
import java.util.List;

/**
 * @author liufq
 */
public class CusUrMbrGiftCardVO extends CusUrMbrGiftCardPO {
    private Integer number;
    private BigDecimal changeBlance;
    private BigDecimal changeGiveBlance;
    private List<String> cardNoList;
    private String startDate;
    private String endDate;
    private String excelUrl;
    private String opeType;
    private List<Long> giftCardIdList;
    private String startValidityDate;
    private String endValidityDate;
    private Integer pageNumber = 1;
    private Integer pageSize = 10;
    /**
     * 操作金额类型 1操作本金,2操作赠送
     */
    private Integer operationAmountType;

    public Integer getNumber() {
        return number;
    }

    public void setNumber(Integer number) {
        this.number = number;
    }


    public BigDecimal getChangeBlance() {
        return changeBlance;
    }

    public void setChangeBlance(BigDecimal changeBlance) {
        this.changeBlance = changeBlance;
    }

    public BigDecimal getChangeGiveBlance() {
        return changeGiveBlance;
    }

    public void setChangeGiveBlance(BigDecimal changeGiveBlance) {
        this.changeGiveBlance = changeGiveBlance;
    }

    public List<String> getCardNoList() {
        return cardNoList;
    }

    public void setCardNoList(List<String> cardNoList) {
        this.cardNoList = cardNoList;
    }

    public String getStartDate() {
        return startDate;
    }

    public void setStartDate(String startDate) {
        this.startDate = startDate;
    }

    public String getEndDate() {
        return endDate;
    }

    public void setEndDate(String endDate) {
        this.endDate = endDate;
    }

    public String getExcelUrl() {
        return excelUrl;
    }

    public void setExcelUrl(String excelUrl) {
        this.excelUrl = excelUrl;
    }

    public String getOpeType() {
        return opeType;
    }

    public void setOpeType(String opeType) {
        this.opeType = opeType;
    }

    public List<Long> getGiftCardIdList() {
        return giftCardIdList;
    }

    public void setGiftCardIdList(List<Long> giftCardIdList) {
        this.giftCardIdList = giftCardIdList;
    }

    public Integer getPageNumber() {
        return pageNumber;
    }

    public void setPageNumber(Integer pageNumber) {
        this.pageNumber = pageNumber;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public String getStartValidityDate() {
        return startValidityDate;
    }

    public void setStartValidityDate(String startValidityDate) {
        this.startValidityDate = startValidityDate;
    }

    public String getEndValidityDate() {
        return endValidityDate;
    }

    public void setEndValidityDate(String endValidityDate) {
        this.endValidityDate = endValidityDate;
    }

    public Integer getOperationAmountType() {
        return operationAmountType;
    }

    public void setOperationAmountType(Integer operationAmountType) {
        this.operationAmountType = operationAmountType;
    }
}
